SystemOrganization addCategory: #Estanciero!

TestCase subclass: #TestsEstanciero
	instanceVariableNames: 'apo fede agus banco tablero salida formosa zonaSurF zonaCentroF zonaNorteF premioGanadero empresaPetrolera salta zonaSurS zonaCentroS zonaNorteS bodega tucuman zonaSurT zonaNorteT fabrica cordoba zonaSurC zonaCentroC zonaNorteC juego prision'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:55'!
setUp 
	
	"Creamos banco"
	banco := Banco new.
	
	"Creamos tablero"
	tablero := Tablero creaUnTableroConBanco: banco.
		
	"Creamos jugadores"
	apo := Participante crearUnParticipanteConEstrategia: Standard YDinero: 50000 enElTablero: tablero. 
	fede := Participante crearUnParticipanteConEstrategia: Standard YDinero: 10000 enElTablero: tablero.
	agus := Participante crearUnParticipanteConEstrategia: Standard YDinero: 0 enElTablero: tablero.
	
	"Creamos Casilleros de salida, prision y premio"
	prision := Prision creaUnaPrisionEnElTablero: tablero.
	salida := Salida creaUnaSalidaEnElTablero: tablero.
	premioGanadero := Premio creaUnPremioEnElTablero: tablero.

	"Creamos provincias"
	formosa := Provincia creaProvinciaConTablero: tablero.
	salta := Provincia creaProvinciaConTablero: tablero.
	tucuman := Provincia creaProvinciaConTablero: tablero.
	cordoba := Provincia creaProvinciaConTablero: tablero.

	"Creamos campos"		
	zonaSurF := Campo unCampoEn: formosa conPrecio: 1000 conValorRenta: 500 conUnCostoDeConstruccionDeEstancia: 500 conDueo: apo.
	zonaCentroF := Campo unCampoEn: formosa conPrecio: 1000 conValorRenta: 500 conUnCostoDeConstruccionDeEstancia: 250 conDueo: fede.
	zonaNorteF := Campo unCampoEn: formosa conPrecio: 1200 conValorRenta: 600 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaSurS := Campo unCampoEn: salta conPrecio: 2600 conValorRenta: 800 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaCentroS := Campo unCampoEn: salta conPrecio: 2600 conValorRenta: 850 conUnCostoDeConstruccionDeEstancia: 300 conDueo: banco.
	zonaNorteS := Campo unCampoEn: salta conPrecio: 3000 conValorRenta: 900 conUnCostoDeConstruccionDeEstancia: 350 conDueo: banco.
	zonaSurT := Campo unCampoEn: tucuman conPrecio: 5000 conValorRenta: 1000 conUnCostoDeConstruccionDeEstancia: 400 conDueo: apo.
	zonaNorteT := Campo unCampoEn: tucuman conPrecio: 5400 conValorRenta: 1200 conUnCostoDeConstruccionDeEstancia: 500 conDueo: apo.
	zonaNorteT cantidadEstancias: 1.
	zonaSurC := Campo unCampoEn: cordoba conPrecio: 6000 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 800 conDueo: fede.
	zonaCentroC := Campo unCampoEn: cordoba conPrecio: 6000 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 800 conDueo: fede.
	zonaNorteC:= Campo unCampoEn: cordoba conPrecio: 6400 conValorRenta: 1500 conUnCostoDeConstruccionDeEstancia: 900 conDueo: fede.

	"Creamos empresas"	
	fabrica := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 150 EnElTablero: tablero ConPrecio: 380 conDueo: banco.
	bodega := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 150 EnElTablero: tablero ConPrecio: 380 conDueo: fede.
	empresaPetrolera := EmpresaConRentaFija creaUnaEmpresaConRentaFija: 200 EnElTablero: tablero ConPrecio: 380 conDueo: fede.

	"Creamos juego"
	juego := Juego creaUnJuegoConTablero: tablero yJugadores: {apo.fede} asOrderedCollection.! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:29'!
testAlConsultarLosDueosDeFormosaDevuelveApoFedeYBanco
	
	|dueosDeFormosa|
	dueosDeFormosa := formosa dueos.
	self assert: ((dueosDeFormosa includes: apo) and: [(dueosDeFormosa includes: fede) and: [dueosDeFormosa includes: banco]] ).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:32'!
testAlConsultarLosDueosDeTucumanDevuelveApo
	
	|dueosDeTucuman|
	dueosDeTucuman := tucuman dueos.
	self assert: (dueosDeTucuman allSatisfy: [:dueo | dueo=apo]).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:58'!
testApoCompraLaFabricaYAlConsultarLaRentaParaFedeDevuelveUnNumeroEntre60000Y360000

	fabrica := Empresa new.
	fabrica tablero: tablero.
	fabrica precio: 380.
	fabrica dueo: banco.
	apo comprar: fabrica.
	self assert: ((60000 to: 360000) includes: (fabrica rentaPara: fede)).     ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 21:21'!
testApoConstruyeEstanciaEnZonaSurTucumanSuDineroPasaASer49600YElCampoPasaATenerUnaEstancia

	zonaSurT agregarEstanciaDe: apo.
	self assert: (apo dinero = 49600 and: [zonaSurT cantidadEstancias = 1]).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:10'!
testApoHipotecaZonaNorteTucumanLaPropiedadPasaASerDelBancoYApoQuedaConCincuentaYDosMilNovecientosCincuenta
	
	apo hipotecaLaPropiedad: zonaNorteT.
	self assert: zonaNorteT dueo = banco & (apo dinero = 52950)! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 21:27'!
testApoIntentaAgregarEstanciaEnZonaCentroFormosaYSeLanzaErrorYSuDineroYLaCantidadDeEstanciasDelCampoQuedanIntactas

	|dineroAnterior cantEstanciasAnterior|
	
	dineroAnterior := apo dinero.
	cantEstanciasAnterior := zonaCentroF cantidadEstancias.
	self should: [zonaCentroF agregarEstanciaDe: apo.] raise: NoSePuedeConstruirEstanciaError.   
	self assert: (apo dinero = dineroAnterior and: [zonaSurT cantidadEstancias = cantEstanciasAnterior]).
	    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 21:31'!
testApoIntentaConstruirEstanciaEnZonaNorteTucumanYSaltaError

	self should: [zonaNorteT agregarEstanciaDe: apo.] raise: NoSePuedeConstruirEstanciaError.   
	
	    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 21:12'!
testApoLePaga10000AFedeYFedeAumentaSuDineroA20000YAApoLeQuedan40000.

	apo paga: 10000 a: fede.
	self assert: (fede dinero = 20000 and: [apo dinero = 40000]).     ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:52'!
testApoPasaPorLaZonaCentroDeFormosaYElYFedeMantieneSuDinero

	|dineroAnteriorFede dineroAnteriorApo|
	
	dineroAnteriorApo := apo dinero.
	dineroAnteriorFede := fede dinero.
	zonaCentroF paso: apo.
	self assert: (dineroAnteriorApo = apo dinero and: [dineroAnteriorFede = fede dinero]).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 10:07'!
testConsultarLaRentaDeLaBodegaParaApoYDevuelveEntre120000Y720000

	bodega := Empresa new.
	bodega tablero: tablero.
	bodega precio: 380.
	bodega dueo: fede.
	self assert: ((120000 to: 720000) includes: (bodega rentaPara: apo)).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:30'!
testConsultarLaRentaDeLaZonaNorteDeTucumanParaFedeYDevuelve2400

	self assert: ((zonaNorteT rentaPara: fede) = 2400).    
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:29'!
testConsultarLaRentaDeLaZonaSurDeTucumanParaFedeYEs1000

	self assert: ((zonaSurT rentaPara: fede) = 1000).    
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:02'!
testFedeCaeEnLaPrisionYMantieneSusPropiedadesSuDineroYSigueLibre

	|dineroAnterior propiedadesAnterirores|
	
	dineroAnterior := fede dinero.
	propiedadesAnterirores := fede propiedades.
	prision cayo: fede.  
	self assert: (fede dinero = dineroAnterior and: [propiedadesAnterirores == fede propiedades and: [fede estasLibre ]]  ).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:39'!
testFedeCaeEnLaSalidaYSuDineroPasaASer10000

	salida cayo: fede.
	self assert: (fede dinero = 10000).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:00'!
testFedeCaeEnLaZonaCentroDeFormosaYSuDineroNoSeModifica

	|dineroAnterior|
	
	dineroAnterior := fede dinero.
	zonaCentroF cayo: fede.  
	self assert: (dineroAnterior = fede dinero).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:07'!
testFedeCaeEnLaZonaSurDeSaltaYLaCompraYSuDineroPasaASer7400

	zonaSurS cayo: fede.
	self assert: ((fede propiedades includes: zonaSurS) and: [fede dinero = 7400]).      
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:14'!
testFedeCaeEnLaZonaSurDeTucumanFedePasaATener9000yApo51000
	
	zonaSurT cayo: fede.
	self assert: (fede dinero = 9000 and: [apo dinero = 51000]) .      
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:38'!
testFedeCaeEnPremioGanaderoYSuDineroPasaASer12500

	premioGanadero cayo: fede.
	self assert: (fede dinero = 12500).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:14'!
testFedeCompraLaZonaCentroDeCordobaEstandoHipotecadaYFedePasaATener1000YEsDueoDeLaZonaQueYaNoEstaHipotecada
	
	zonaCentroC hipotecate.
	fede comprar: zonaCentroC.
	self assert: fede dinero = 1000 & (zonaCentroC dueo = fede).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:26'!
testFedeEstaEnPremioGanaderoYJuegaYEstaEnOtroCasillero

	|numeroDado  casilleros |
	fede posicionEnTablero: premioGanadero .
	numeroDado := fede tirarDados.
	[fede estado jugo: fede saco: numeroDado .] on: EstasEnBancarrotaError do: [:e | self jugadores remove: fede .].
	self assert: (fede posicionEnTablero ~= premioGanadero )  	
	
	      ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:02'!
testFedeEstaPresoHace1TurnoSaca4Y5YSiguePreso

	fede ponetePreso.
	fede cantidadTurnosPreso: 1.
	fede saco: 4 y: 5.
	fede estado jugo: fede saco: 9. 
	self assert: (fede estasPreso).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 16:46'!
testFedeEstaPresoHace1TurnoSacaDoble3YEstaLibre

	fede ponetePreso.
	fede cantidadTurnosPreso: 1.
	fede saco: 3 y: 3.
	fede estado jugo: fede saco: 6. 
	self assert: (fede estasLibre).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:13'!
testFedeEstaPresoHace3TurnosYSaqueLoQueSaqueEstaLibre

	fede ponetePreso.
	fede cantidadTurnosPreso:3.
	fede saco: 1 y: 6 .
	fede estado jugo: fede saco: 7.         
	self assert: (fede estasLibre).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:11'!
testFedeHipotecaLaBodegaQuePasaASerDelBancoYFedeQuedaConDiezMilCientoNoventaPesos
	
	fede hipotecaLaPropiedad: bodega.
	self assert: bodega dueo = banco & (fede dinero = 10190)! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:12'!
testFedeHipotecaZonaNorteCordobaLaPropiedadPasaASerDelBancoYFedeQuedaConTreceMilDoscientos
	
	fede hipotecaLaPropiedad: zonaNorteC.
	self assert: zonaNorteC dueo = banco & (fede dinero = 13200).! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:12'!
testFedeLePaga12000AApoEntoncesFedeHipotecaLaZonaNorteDeCordobaYQuedariaCon1200Pesos
	
	fede hipotecaLaPropiedad: zonaNorteC.
	fede paga: 12000 a: apo.
	self assert: fede dinero = 1200! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:03'!
testFedeLePaga50000AApoTieneQueSerUnErrorDeBancarrotaYNoDebeModificarseElDinero
	
	| dineroApo dineroFede |
	dineroApo := apo dinero.
	dineroFede := fede dinero.
	self should: [fede paga: 50000 a: apo.] raise: EstasEnBancarrotaError.
	self assert: apo dinero = dineroApo & (fede dinero = dineroFede).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:02'!
testFedePasaPorLaPrisionYMantieneSusPropiedadesSuDineroYSigueLibre

	|dineroAnterior propiedadesAnterirores|
	
	dineroAnterior := fede dinero.
	propiedadesAnterirores := fede propiedades.
	prision paso: fede.  
	self assert: (fede dinero = dineroAnterior and: [propiedadesAnterirores == fede propiedades and: [fede estasLibre ]]  ).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:45'!
testFedePasaPorLaSalidaYSuDineroEs15000

	salida paso: fede.
	self assert: (fede dinero = 15000).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:40'!
testFedePasaPorPremioGanaderoYMantieneSuDinero

	|dineroAnterior|
	dineroAnterior := fede dinero.
	premioGanadero paso: fede.
	self assert: (fede dinero = dineroAnterior).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 16:39'!
testFedeSacaDoble2YLuegoSaca4y5YNoEstaPreso

	fede saco: 2 y: 2.
	fede estado jugo: fede saco: 4.   
	fede saco: 4 y: 5.
	fede estado jugo: fede saco: 9.
	self deny: (fede estasPreso).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 16:41'!
testFedeSacaDoble2YLuegoSacaDoble4YEstaPreso

	fede saco: 2 y: 2.
	fede estado jugo: fede saco: 4.   
	fede saco: 4 y: 4.
	fede estado jugo: fede saco: 8.
	self assert: (fede estasPreso).     
	   ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 18:21'!
testFedeSeMuevePorZonaCentroDeCordobaSalidaYZonaSurDeFormosaSuDineroPasaASer14500YQuedaEnZonaSurDeFormosa

	|casilleros|
	
	casilleros := OrderedCollection new.
	casilleros add: zonaNorteC .
	casilleros add: salida .
	casilleros add: zonaSurF.
	
	fede moveteUnos: casilleros.
	self assert: (fede dinero = 14500 and: [fede posicionEnTablero = zonaSurF]).        ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:36'!
testLaCantidadDeEmpresasDeFedeEs2

	self assert: (fede cantidadEmpresas = 2).    ! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:56'!
testSiApoEsGarcaYCaeFabricaEntoncesLaCompraYQuedaCon49620Pesos
	
	apo estrategia: Garca new.
	fabrica cayo: apo.
	self assert: (fabrica dueo = apo and: [ apo dinero = 49620 .]).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:55'!
testSiApoEsImperialistaYCaeFabricaEntoncesLaCompraYQuedaCon49620Pesos
	
	| dineroAnterior |

	dineroAnterior := apo dinero.	
	apo estrategia: Imperialista new.
	fabrica cayo: apo.
	self assert: (fabrica dueo = banco and: [ apo dinero = dineroAnterior .]).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:56'!
testSiApoEsImperialistaYCaeFabricaEntoncesNoLaCompraYElDineroLeQuedaIgual
	
	| dineroAnterior |

	dineroAnterior := apo dinero.	
	apo estrategia: Imperialista new.
	fabrica cayo: apo.
	self assert: (fabrica dueo = banco and: [ apo dinero = dineroAnterior .]).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:43'!
testSiApoEsImperialistaYCaeZonaSurCEntoncesNoLaCompra
	
	apo estrategia: Imperialista new.
	zonaSurC cayo: apo.
	self assert: (zonaSurS dueo = banco).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:15'!
testSiFedeEsGarcaYCaeZonaNorteFYLaCompraQuedaCon8800Pesos
	
	fede estrategia: Garca new.
	zonaNorteF cayo: fede.
	self assert: (fede dinero = 8800).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:18'!
testSiFedeEsGarcaYCaeZonaSurSYLaCompraQuedaCon7400Pesos
	
	fede estrategia: Garca new.
	zonaSurS cayo: fede.
	self assert: (fede dinero = 7400).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:20'!
testSiFedeEsImperialistaYCaeZonaNorteFYLaCompraQuedaCon8800Pesos
	
	fede estrategia: Imperialista new.
	zonaNorteF cayo: fede.
	self assert: (fede dinero = 8800).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:20'!
testSiFedeEsImperialistaYCaeZonaSurSYLaCompraQuedaCon7400Pesos
	
	fede estrategia: Imperialista new.
	zonaSurS cayo: fede.
	self assert: (fede dinero = 7400).
! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 08:11'!
testSiSamuelEsGarcaYCaeZonaNorteFYLaCompraQuedaCon8800Pesos


! !

!TestsEstanciero methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:55'!
testUnaTiradaDeDadosDaEntre2Y12

	self assert: ((2 to: 12) includes: fede tirarDados).    ! !

Object subclass: #Casillero
	instanceVariableNames: 'tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Casillero methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:56'!
cayo: unJugador
	"Si el casillero no entendio antes que hacer no tiene que hacer nada"! !

!Casillero methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:56'!
paso: unJugador
	"Si el casillero no entendio antes que hacer no tiene que hacer nada"! !

!Casillero methodsFor: 'setter' stamp: 'Federico 10/15/2012 08:48'!
sosEmpresa
	^false.! !

!Casillero methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:02'!
tablero
	^tablero.! !

!Casillero methodsFor: 'setter' stamp: 'Federico 9/6/2012 22:23'!
tablero: tableroActual
	tablero := tableroActual.
	tableroActual agregarCasilleros: self.! !

Casillero subclass: #Premio
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Premio class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:43'!
creaUnPremioEnElTablero: unTablero

	| unPremio |
	unPremio := self new.
	unPremio tablero: unTablero.
	^unPremio.! !

!Premio methodsFor: 'as yet unclassified' stamp: 'Apo 9/6/2012 16:08'!
cayo: jugador
	jugador recibe: 2500.! !

Casillero subclass: #Prision
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Prision class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 14:10'!
creaUnaPrisionEnElTablero: unTablero

	| unaPrision |
	unaPrision := self new.
	unaPrision tablero: unTablero.
	unTablero prision: unaPrision.
	^unaPrision.! !

Casillero subclass: #Propiedad
	instanceVariableNames: 'precio dueo'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Propiedad subclass: #Campo
	instanceVariableNames: 'provincia valorRenta costoConstruccionEstancia cantidadEstancias'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Campo class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:08'!
unCampoEn: unaProvincia conPrecio: unPrecio conValorRenta: unaRenta conUnCostoDeConstruccionDeEstancia: unCosto conDueo: unDueo
	| nuevoCampo |
	nuevoCampo := Campo new.
	nuevoCampo provincia: unaProvincia.
	unDueo agregarPropiedad:  nuevoCampo.
	nuevoCampo tablero: unaProvincia tablero. "Hace que el casillero entienda cual es su tablero"
	nuevoCampo precio: unPrecio.
	nuevoCampo valorRenta: unaRenta.
	nuevoCampo costoConstruccionEstancia: unCosto.
	^nuevoCampo.! !

!Campo methodsFor: 'getter' stamp: 'Federico 9/18/2012 10:35'!
agregarEstanciaDe: jugador
	self provincia verificaConstruccionEn:  self .
	jugador comprarEstanciaEn: self. 
	self cantidadEstancias: self cantidadEstancias + 1. ! !

!Campo methodsFor: 'getter' stamp: 'Apo 9/6/2012 19:02'!
cantidadEstancias
	^cantidadEstancias.! !

!Campo methodsFor: 'setter' stamp: 'Apo 9/6/2012 19:01'!
cantidadEstancias: unaCantEstancias
	cantidadEstancias := unaCantEstancias. ! !

!Campo methodsFor: 'getter' stamp: 'Federico 9/3/2012 23:15'!
costoConstruccionEstancia
	^costoConstruccionEstancia.! !

!Campo methodsFor: 'setter' stamp: 'Federico 9/3/2012 23:15'!
costoConstruccionEstancia: costoActual
	costoConstruccionEstancia := costoActual.! !

!Campo methodsFor: 'as yet unclassified' stamp: 'Federico 9/11/2012 05:25'!
initialize 
	cantidadEstancias := 0.! !

!Campo methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:19'!
provincia
	^provincia.! !

!Campo methodsFor: 'setter' stamp: 'Federico 10/9/2012 15:04'!
provincia: provinciaActual
	provincia := provinciaActual.
	provinciaActual agregarCampos: self. "Le dice a la provincia que tiene un campo nuevo para agregar"! !

!Campo methodsFor: 'as yet unclassified' stamp: 'Apo 9/6/2012 19:44'!
renta: cantEstancias
	^(2 raisedTo:  cantEstancias) * valorRenta.! !

!Campo methodsFor: 'setter' stamp: 'Federico 9/15/2012 20:05'!
rentaPara: jugador
	^self renta: self cantidadEstancias.! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 11:30'!
sosAptaParaElGarca: unJugador 

	| propiedades |
	propiedades := self tablero empresas.
	^propiedades anySatisfy: [:propiedad | (propiedad dueo ~= self dueo) | (propiedad dueo ~= unJugador) .].! !

!Campo methodsFor: 'getter' stamp: 'Federico 10/15/2012 11:25'!
sosAptaParaElImperialista: unJugador
	
	| propiedades |
	propiedades := self provincia campos.
	^ (propiedades anySatisfy: [:propiedad | propiedad dueo = unJugador .]) | (propiedades allSatisfy: [:propiedad | propiedad dueo = self dueo .]).! !

!Campo methodsFor: 'getter' stamp: 'Federico 9/3/2012 23:14'!
valorRenta
	^valorRenta.! !

!Campo methodsFor: 'setter' stamp: 'Federico 9/3/2012 23:14'!
valorRenta: rentaActual
	valorRenta := rentaActual.! !

Propiedad subclass: #Empresa
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Empresa class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:44'!
creaUnaEmpresaEnElTablero: unTablero ConPrecio: unPrecio conDueo: unDueo

	| unaEmpresa |
	unaEmpresa := self new.
	unaEmpresa tablero: unTablero.
	unaEmpresa precio: unPrecio.
	unDueo agregarPropiedad: unaEmpresa.
	^unaEmpresa.! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 21:12'!
renta: numeroDado
	^numeroDado * 30000 * self dueo cantidadEmpresas.! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 17:53'!
rentaPara: jugador
	^self renta: (jugador tirarDado + jugador tirarDado).! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:29'!
sosAptaParaElGarca: unJugador
	
	| propiedades |
	propiedades := self tablero empresas.
	^propiedades anySatisfy: [:propiedad | (propiedad dueo ~= self dueo) | (propiedad dueo ~= unJugador) .].
	! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:25'!
sosAptaParaElImperialista: unJugador

	^ self tablero empresas allSatisfy: [:propiedad | propiedad dueo = self dueo.] ! !

!Empresa methodsFor: 'as yet unclassified' stamp: 'Federico 9/4/2012 11:18'!
sosEmpresa
	^true.! !

Empresa subclass: #EmpresaConRentaFija
	instanceVariableNames: 'rentaFija'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!EmpresaConRentaFija class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:44'!
creaUnaEmpresaConRentaFija: unaRentaFija EnElTablero: unTablero ConPrecio: unPrecio conDueo: unDueo

	| unaEmpresa |
	unaEmpresa := self new.
	unaEmpresa tablero: unTablero.
	unaEmpresa precio: unPrecio.
	unaEmpresa rentaFija: unaRentaFija.
	unDueo agregarPropiedad: unaEmpresa.
	^unaEmpresa.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 9/15/2012 20:18'!
rentaFija 
	^rentaFija.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 9/15/2012 20:18'!
rentaFija: rentaActual
	rentaFija := rentaActual.! !

!EmpresaConRentaFija methodsFor: 'as yet unclassified' stamp: 'Federico 9/15/2012 20:17'!
rentaPara: jugador
	^self rentaFija.! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 9/18/2012 10:44'!
cayo: jugador
	(self dueo ~= jugador) ifTrue: [self dueo teVisito: jugador en: self.].! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 9/3/2012 19:08'!
dueo
	^dueo.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 9/3/2012 19:08'!
dueo: nuevoDueo
	dueo := nuevoDueo.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 10/15/2012 10:42'!
hipotecate
	self precio: self precio * 1.5.
	self dueo: self tablero banco .
	! !

!Propiedad methodsFor: 'getter' stamp: 'Federico 9/3/2012 19:09'!
precio
	^precio.! !

!Propiedad methodsFor: 'setter' stamp: 'Federico 9/3/2012 19:09'!
precio: nuevoPrecio
	precio := nuevoPrecio.! !

Casillero subclass: #Salida
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Salida class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:41'!
creaUnaSalidaEnElTablero: unTablero
	
	| unaSalida |
	unaSalida := self new.
	unaSalida tablero: unTablero.
	^unaSalida.! !

!Salida methodsFor: 'as yet unclassified' stamp: 'Federico 9/11/2012 21:56'!
paso: unJugador
	unJugador recibe: 5000.! !

Object subclass: #Garca
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Garca methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:30'!
compra: jugador SiQueres: propiedad

	(propiedad sosAptaParaElGarca: jugador ) ifTrue: [ jugador comprar: propiedad .].! !

Object subclass: #Imperialista
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Imperialista methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:25'!
compra: jugador SiQueres: propiedad

	(propiedad sosAptaParaElImperialista: jugador) ifTrue: [ jugador comprar: propiedad .].! !

Object subclass: #Juego
	instanceVariableNames: 'jugadores tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Juego class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:46'!
creaUnJuegoConTablero: unTablero yJugadores: coleccionDeJugadores
	
	| unJuego |	
	unJuego := self new.
	unJuego tablero: unTablero.
	coleccionDeJugadores do: [:unJugador | unJuego agregarJugador: unJugador . ].
	^unJuego.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:46'!
agregarJugador: jugadorNuevo
	jugadores add: jugadorNuevo.
	jugadorNuevo posicionEnTablero: self tablero casilleros first.  "Pone el jugador nuevo en la salida (primer casillero del tablero)"! !

!Juego methodsFor: 'as yet unclassified' stamp: 'AgustinCroce 10/13/2012 16:36'!
casillerosPara: unJugador con: numeroDado
	^self tablero casillerosDesde: unJugador posicionEnTablero hasta: numeroDado. ! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 9/11/2012 05:20'!
initialize
	jugadores := OrderedCollection new.! !

!Juego methodsFor: 'getter' stamp: 'Federico 9/3/2012 20:55'!
jugadores
	^jugadores.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 10/3/2012 18:29'!
queJuegue: unJugador
	|numeroDado  casilleros |
	numeroDado := unJugador tirarDados.
	[unJugador estado jugo: unJugador saco: numeroDado .] on: EstasEnBancarrotaError do: [:e | self jugadores remove: unJugador .].	
	self queJuegueElQueSigue.! !

!Juego methodsFor: 'as yet unclassified' stamp: 'Federico 9/3/2012 19:20'!
queJuegueElQueSigue
	| elQueSigue |
	elQueSigue := self jugadores add: self jugadores removeFirst.
	self queJuegue: elQueSigue.! !

!Juego methodsFor: 'getter' stamp: 'Federico 9/6/2012 22:16'!
tablero
	^tablero.! !

!Juego methodsFor: 'setter' stamp: 'Federico 9/6/2012 22:16'!
tablero: tableroActual
	tablero := tableroActual.! !

Object subclass: #Jugador
	instanceVariableNames: 'propiedades tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Jugador subclass: #Banco
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 9/8/2012 10:50'!
recibe: unDinero 
	"El banco no recibe plata ya que su dinero es infinito"! !

!Banco methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:19'!
teVisito: jugador en: propiedad
	jugador estrategia compra: jugador SiQueres: propiedad.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:10'!
agregarPropiedad: nuevaPropiedad
	self propiedades add: nuevaPropiedad.
	nuevaPropiedad dueo: self.! !

!Jugador methodsFor: 'accessing' stamp: 'Federico 9/17/2012 21:43'!
initialize
	propiedades := OrderedCollection new.! !

!Jugador methodsFor: 'getter' stamp: 'Federico 9/17/2012 21:43'!
propiedades 
	^propiedades.! !

!Jugador methodsFor: 'getter' stamp: 'Federico 10/3/2012 16:22'!
tablero
	^tablero! !

!Jugador methodsFor: 'setter' stamp: 'Federico 10/3/2012 16:22'!
tablero: tableroActual
	tablero := tableroActual.! !

Jugador subclass: #Participante
	instanceVariableNames: 'dinero posicionEnTablero cantidadDeDoble cantidadTurnosPreso estado estrategia'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Participante class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:26'!
crearUnParticipanteConEstrategia: unaEstrategia YDinero: unDinero enElTablero: unTablero

	| participante |
	participante := self new.
	participante estrategia: unaEstrategia new.  
	participante dinero: unDinero.   
	participante tablero: unTablero.
	^participante.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 9/17/2012 21:16'!
avanzarPor: casilleros 
	casilleros do: [ : unCasillero | unCasillero paso: self].! !

!Participante methodsFor: 'accessing' stamp: 'Federico 9/17/2012 21:18'!
caerEn: casillero
	casillero cayo: self.
	self posicionEnTablero: casillero.! !

!Participante methodsFor: 'getter' stamp: 'AgustinCroce 10/13/2012 16:15'!
cantidadDeDoble 

	^cantidadDeDoble ! !

!Participante methodsFor: 'setter' stamp: 'AgustinCroce 10/13/2012 16:14'!
cantidadDeDoble: unNumero

	cantidadDeDoble := unNumero .! !

!Participante methodsFor: 'accessing' stamp: 'Federico 9/22/2012 05:35'!
cantidadEmpresas
	^self propiedades count: [:propiedad | propiedad sosEmpresa. ].! !

!Participante methodsFor: 'getter' stamp: 'Federico 10/3/2012 16:30'!
cantidadTurnosPreso
	^cantidadTurnosPreso! !

!Participante methodsFor: 'setter' stamp: 'Federico 10/3/2012 16:31'!
cantidadTurnosPreso: cantidadPresoActual
	cantidadTurnosPreso := cantidadPresoActual.! !

!Participante methodsFor: 'setter' stamp: 'Federico 10/3/2012 16:16'!
casillerosPara: numeroDado
	^self tablero casillerosDesde: self posicionEnTablero hasta: numeroDado. ! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:06'!
comprar: propiedad
	self pagar: propiedad precio.
	self agregarPropiedad: propiedad.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 9/17/2012 21:10'!
comprarEstanciaEn: campo
	self pagar: campo costoConstruccionEstancia . ! !

!Participante methodsFor: 'getter' stamp: 'Federico 9/3/2012 19:11'!
dinero
	^dinero.! !

!Participante methodsFor: 'setter' stamp: 'Federico 9/3/2012 19:11'!
dinero: dineroActual
	dinero := dineroActual.! !

!Participante methodsFor: 'getter' stamp: 'Federico 10/3/2012 16:32'!
estado
	^estado! !

!Participante methodsFor: 'setter' stamp: 'Federico 10/3/2012 16:32'!
estado: estadoActual
	estado := estadoActual .! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/14/2012 21:12'!
estasLibre

	^self estado sosLibre.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/14/2012 21:12'!
estasPreso

	^self estado sosPreso.! !

!Participante methodsFor: 'getter' stamp: 'Federico 10/3/2012 16:43'!
estrategia
	^estrategia! !

!Participante methodsFor: 'setter' stamp: 'Federico 10/3/2012 16:43'!
estrategia: estrategiaActual
	estrategia := estrategiaActual! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:00'!
hipotecaAlgunaPropiedad

	self hipotecaLaPropiedad: self propiedades anyOne..
	
	
	! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:08'!
hipotecaLaPropiedad: propiedad
	
	self recibe: (propiedad precio / 2).
	propiedad sosEmpresa
		ifFalse: [self recibe: (propiedad cantidadEstancias * propiedad costoConstruccionEstancia / 2)].
	propiedad hipotecate.
	self propiedades remove: propiedad.
	
	
	! !

!Participante methodsFor: 'accessing' stamp: 'AgustinCroce 10/13/2012 16:20'!
initialize 

	self estado: Libre new.
	self cantidadDeDoble: 0.
	super initialize .! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:41'!
jugaComoLibreSacaste: numeroDado.

	self cantidadDeDoble = 2 ifTrue: [ self ponetePreso .] ifFalse: [ self moveteUnos: (self casillerosPara: numeroDado) .]. ! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 11:39'!
jugaComoPresoSacaste: numeroDado
	 
	(self cantidadDeDoble = 1) | (self cantidadTurnosPreso = 3) 
		ifTrue: 
			[ self poneteLibre .  
			  self moveteUnos: (self casillerosPara: numeroDado) .] 
		ifFalse: 
			[ self cantidadTurnosPreso: self cantidadTurnosPreso + 1 .].! !

!Participante methodsFor: 'accessing' stamp: 'Federico 9/18/2012 10:46'!
moveteUnos: casilleros
	self avanzarPor: casilleros.
	self caerEn: casilleros last.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
paga: plata a: otroJugador 

	(self ~= otroJugador) 
		ifTrue: [self pagar: plata.
				otroJugador recibe: plata.].! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
pagar: plata

	self verificaPosiblePago: plata.
	self dinero: self dinero - plata. ! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
poneteLibre 

	self estado: Libre new.
	self cantidadDeDoble: 0.
	self cantidadTurnosPreso: 0.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:13'!
ponetePreso 

	self estado: Preso new.
	self cantidadDeDoble: 0.
	self posicionEnTablero: tablero prision.! !

!Participante methodsFor: 'getter' stamp: 'Federico 10/15/2012 14:00'!
posicionEnTablero

	^posicionEnTablero.! !

!Participante methodsFor: 'setter' stamp: 'Federico 10/15/2012 14:00'!
posicionEnTablero: posicionActual

	posicionEnTablero := posicionActual.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
recibe: unDinero 

	self dinero: self dinero + unDinero.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:00'!
sacasteDoble 

	self cantidadDeDoble: self cantidadDeDoble + 1.! !

!Participante methodsFor: 'accessing' stamp: 'AgustinCroce 10/13/2012 16:03'!
saco: unDado y: otroDado

	unDado = otroDado ifTrue: [self sacasteDoble. ] ifFalse: [self cantidadDeDoble: 0. ]   ! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
teVisito: jugador en: propiedad
	
	| renta |
	renta := propiedad rentaPara: jugador.
	jugador pagar: renta. 
	self recibe: renta.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 10:47'!
tenesQueHipotecarPara: plataAPagar 
	
	self verificaPosibleHipoteca.
	self hipotecaAlgunaPropiedad.
	self dinero >= plataAPagar ifFalse: [self tenesQueHipotecarPara: plataAPagar.].! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
tirarDado

	^(1to: 6) atRandom.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
tirarDados

	| dado1 dado2 |
	dado1 := self tirarDado.
	dado2 := self tirarDado.
	self saco: dado1 y: dado2 .
	^dado1+ dado2.! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/3/2012 18:29'!
verificaPosibleHipoteca

	self propiedades size > 0
		ifFalse: 
			[ EstasEnBancarrotaError signal .].! !

!Participante methodsFor: 'accessing' stamp: 'Federico 10/15/2012 13:59'!
verificaPosiblePago: plata
	
	self dinero >= plata ifFalse: [self tenesQueHipotecarPara: plata]! !

Object subclass: #Libre
	instanceVariableNames: 'campos tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:40'!
jugo: unJugador saco: numeroDado
	
	unJugador jugaComoLibreSacaste: numeroDado.! !

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosLibre 

	^true.! !

!Libre methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:12'!
sosPreso 

	^false.! !

Object subclass: #Preso
	instanceVariableNames: 'campos tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:40'!
jugo: unJugador saco: numeroDado
	
	unJugador jugaComoPresoSacaste: numeroDado.! !

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosLibre 

	^false.! !

!Preso methodsFor: 'as yet unclassified' stamp: 'Federico 10/14/2012 21:11'!
sosPreso

	^true.! !

Object subclass: #Provincia
	instanceVariableNames: 'campos tablero'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Provincia class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 13:35'!
creaProvinciaConTablero: unTablero 

	| unaProvincia |
	unaProvincia := self new.
	unaProvincia tablero: unTablero.
	^unaProvincia.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 22:09'!
agregarCampos: nuevoCampo
	campos add: nuevoCampo.! !

!Provincia methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:17'!
campos
	^campos.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 9/4/2012 01:59'!
construccionParejaEn: campo
	^campos allSatisfy: [:unCampo | campo cantidadEstancias <= unCampo cantidadEstancias. ].! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 22:07'!
dueos
	^(campos collect: [:unCampo | unCampo dueo. ]) asSet.! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 9/17/2012 21:25'!
esProvinciaMonopolica
	| dueo |
	dueo := campos first dueo.
	^campos allSatisfy: [:campo | campo dueo = dueo].! !

!Provincia methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 22:05'!
initialize 
	campos := OrderedCollection new.
	 ! !

!Provincia methodsFor: 'setter' stamp: 'Federico 9/17/2012 21:24'!
sePuedeConstruirEn: campo
	self verificaConstruccionEn: campo.
	^true.! !

!Provincia methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:46'!
tablero
	^tablero.! !

!Provincia methodsFor: 'setter' stamp: 'Federico 9/6/2012 22:24'!
tablero: tableroActual
	tablero := tableroActual.
	tableroActual agregarProvincias: self.! !

!Provincia methodsFor: 'setter' stamp: 'Federico 10/15/2012 11:36'!
verificaConstruccionEn: campo
	(self esProvinciaMonopolica and: [ self construccionParejaEn: campo. ]) ifFalse: [NoSePuedeConstruirEstanciaError signal .].! !

Object subclass: #Standard
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Standard methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 11:20'!
compra: jugador SiQueres: propiedad
	jugador comprar: propiedad.! !

Object subclass: #Tablero
	instanceVariableNames: 'banco casilleros provincias prision'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

!Tablero class methodsFor: 'as yet unclassified' stamp: 'Federico 10/15/2012 12:57'!
creaUnTableroConBanco: unBanco
	
	| unTablero |
	unTablero := self new.
	unTablero banco: unBanco.
	^unTablero.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 22:10'!
agregarCasilleros: casilleroNuevo
	casilleros add: casilleroNuevo.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 9/6/2012 22:10'!
agregarProvincias: nuevaProvincia
	provincias add: nuevaProvincia.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:08'!
banco
	^banco.! !

!Tablero methodsFor: 'setter' stamp: 'Federico 9/6/2012 08:33'!
banco: bancoActual
	banco := bancoActual.
	bancoActual tablero: self.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:11'!
casilleros
	^casilleros.! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Apo 9/6/2012 17:27'!
casillerosDesde: casilleroInicial hasta: unNumero
	| misCasilleros recorrido |
	misCasilleros := self casilleros copyAfter: casilleroInicial.
	recorrido := OrderedCollection new.
	[ recorrido size >= unNumero ] whileFalse: [
	misCasilleros ifEmpty: [
	misCasilleros addAll: self casilleros.
	].
	recorrido add: misCasilleros removeFirst. ].

	^recorrido.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 10/15/2012 08:50'!
empresas
	
	^self casilleros select: [:casillero | casillero sosEmpresa . ].
	! !

!Tablero methodsFor: 'as yet unclassified' stamp: 'Federico 9/11/2012 05:20'!
initialize
	casilleros := OrderedCollection new.
	provincias := OrderedCollection new.! !

!Tablero methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:12'!
prision
	^ prision.! !

!Tablero methodsFor: 'accessing' stamp: 'Federico 10/15/2012 14:12'!
prision: unaPrision 

	prision := unaPrision.! !

!Tablero methodsFor: 'getter' stamp: 'Federico 9/3/2012 21:48'!
provincias
	^provincias! !

Error subclass: #EstasEnBancarrotaError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!

Error subclass: #NoSePuedeConstruirEstanciaError
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Estanciero'!
